Learn R Programming

robustcov (version 0.1)

covSpearmanU: SpearmanU estimator for *covariance*

Description

This routine calculates the SpearmanU, the pairwise covariance matrix estimator proposed in Oellererand Croux

Usage

covSpearmanU(data)

Arguments

data

the n by p raw data matrix

Value

a matrix with dimension p by p of spearmanU correlation

Examples

Run this code
# NOT RUN {
covSpearmanU(matrix(rnorm(500),100,5)) 
# }

Run the code above in your browser using DataLab