The full dataset, should be a matrix or a data.frame, row as sample
k
number of folds
covest
a *function* or name of a function (string) that takes a matrix to estimate covariance
rhos
a vector of tuning parameter to be tested
evaluation
a *function* or name of a function (string) that takes only two arguments, the estimated covariance and the test covariance, when NULL, we use negative log likelihood on test sets
...
extra arguments send to glasso
Value
a matrix with k rows, each row is the evaluation loss of that fold