This routine calculate the nearest positive semi0definite projection
nearPPSD(X, eigenTol = 1e-06, convTol = 1e-07, psdTol = 1e-08, maxit = 1000L)the matrix
tolerance in eigen system, used in finding nearest positive matrix
tolerance in cov, used in finding nearest positive matrix
tolerance in psd, used in finding nearest positive matrix
max iterations in finding nearest positive matrix
a matrix which is the nearest positive semi-definite matrix of input X