powered by
This routine calculates the SpearmanU, the pairwise covariance matrix estimator proposed in Oellererand Croux
covSpearmanU(data)
the n by p raw data matrix
a matrix with dimension p by p of spearmanU correlation
# NOT RUN { covSpearmanU(matrix(rnorm(500),100,5)) # }
Run the code above in your browser using DataLab